@@ -582,9 +582,10 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
             node._deleted = True
             return node
 
+        len_raw_d = len(raw_d) if raw_d is not None else None
         with safe_span(
             op=f"parse.{cls._model_name}",
-            description=f"only_one:{only_one}, {len(raw_d)=}",
+            description=f"only_one:{only_one}, {len_raw_d=}",
         ):
             if only_one:
                 return parse_deleted(raw_d)
